import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../../../common";
export interface AggregatorV3InterfaceInterface extends Interface {
    getFunction(nameOrSignature: "decimals" | "description" | "getRoundData" | "latestRoundData" | "version"): FunctionFragment;
    encodeFunctionData(functionFragment: "decimals", values?: undefined): string;
    encodeFunctionData(functionFragment: "description", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRoundData", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "latestRoundData", values?: undefined): string;
    encodeFunctionData(functionFragment: "version", values?: undefined): string;
    decodeFunctionResult(functionFragment: "decimals", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "description", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoundData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "latestRoundData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "version", data: BytesLike): Result;
}
export interface AggregatorV3Interface extends BaseContract {
    connect(runner?: ContractRunner | null): AggregatorV3Interface;
    waitForDeployment(): Promise<this>;
    interface: AggregatorV3InterfaceInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    decimals: TypedContractMethod<[], [bigint], "view">;
    description: TypedContractMethod<[], [string], "view">;
    getRoundData: TypedContractMethod<[
        _roundId: BigNumberish
    ], [
        [
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            roundId: bigint;
            answer: bigint;
            startedAt: bigint;
            updatedAt: bigint;
            answeredInRound: bigint;
        }
    ], "view">;
    latestRoundData: TypedContractMethod<[
    ], [
        [
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            roundId: bigint;
            answer: bigint;
            startedAt: bigint;
            updatedAt: bigint;
            answeredInRound: bigint;
        }
    ], "view">;
    version: TypedContractMethod<[], [bigint], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "decimals"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "description"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "getRoundData"): TypedContractMethod<[
        _roundId: BigNumberish
    ], [
        [
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            roundId: bigint;
            answer: bigint;
            startedAt: bigint;
            updatedAt: bigint;
            answeredInRound: bigint;
        }
    ], "view">;
    getFunction(nameOrSignature: "latestRoundData"): TypedContractMethod<[
    ], [
        [
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            roundId: bigint;
            answer: bigint;
            startedAt: bigint;
            updatedAt: bigint;
            answeredInRound: bigint;
        }
    ], "view">;
    getFunction(nameOrSignature: "version"): TypedContractMethod<[], [bigint], "view">;
    filters: {};
}
