import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../common";
export declare namespace IAaveV3Pool {
    type ReserveConfigurationMapStruct = {
        data: BigNumberish;
    };
    type ReserveConfigurationMapStructOutput = [data: bigint] & {
        data: bigint;
    };
    type ReserveDataStruct = {
        configuration: IAaveV3Pool.ReserveConfigurationMapStruct;
        liquidityIndex: BigNumberish;
        currentLiquidityRate: BigNumberish;
        variableBorrowIndex: BigNumberish;
        currentVariableBorrowRate: BigNumberish;
        currentStableBorrowRate: BigNumberish;
        lastUpdateTimestamp: BigNumberish;
        id: BigNumberish;
        aTokenAddress: AddressLike;
        stableDebtTokenAddress: AddressLike;
        variableDebtTokenAddress: AddressLike;
        interestRateStrategyAddress: AddressLike;
        accruedToTreasury: BigNumberish;
        unbacked: BigNumberish;
        isolationModeTotalDebt: BigNumberish;
    };
    type ReserveDataStructOutput = [
        configuration: IAaveV3Pool.ReserveConfigurationMapStructOutput,
        liquidityIndex: bigint,
        currentLiquidityRate: bigint,
        variableBorrowIndex: bigint,
        currentVariableBorrowRate: bigint,
        currentStableBorrowRate: bigint,
        lastUpdateTimestamp: bigint,
        id: bigint,
        aTokenAddress: string,
        stableDebtTokenAddress: string,
        variableDebtTokenAddress: string,
        interestRateStrategyAddress: string,
        accruedToTreasury: bigint,
        unbacked: bigint,
        isolationModeTotalDebt: bigint
    ] & {
        configuration: IAaveV3Pool.ReserveConfigurationMapStructOutput;
        liquidityIndex: bigint;
        currentLiquidityRate: bigint;
        variableBorrowIndex: bigint;
        currentVariableBorrowRate: bigint;
        currentStableBorrowRate: bigint;
        lastUpdateTimestamp: bigint;
        id: bigint;
        aTokenAddress: string;
        stableDebtTokenAddress: string;
        variableDebtTokenAddress: string;
        interestRateStrategyAddress: string;
        accruedToTreasury: bigint;
        unbacked: bigint;
        isolationModeTotalDebt: bigint;
    };
}
export interface IAaveV3PoolInterface extends Interface {
    getFunction(nameOrSignature: "getReserveData" | "getReserveNormalizedIncome" | "supply" | "withdraw"): FunctionFragment;
    encodeFunctionData(functionFragment: "getReserveData", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getReserveNormalizedIncome", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "supply", values: [AddressLike, BigNumberish, AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "withdraw", values: [AddressLike, BigNumberish, AddressLike]): string;
    decodeFunctionResult(functionFragment: "getReserveData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getReserveNormalizedIncome", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
}
export interface IAaveV3Pool extends BaseContract {
    connect(runner?: ContractRunner | null): IAaveV3Pool;
    waitForDeployment(): Promise<this>;
    interface: IAaveV3PoolInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getReserveData: TypedContractMethod<[
        asset: AddressLike
    ], [
        IAaveV3Pool.ReserveDataStructOutput
    ], "view">;
    getReserveNormalizedIncome: TypedContractMethod<[
        underlyingAsset: AddressLike
    ], [
        bigint
    ], "view">;
    supply: TypedContractMethod<[
        asset: AddressLike,
        amount: BigNumberish,
        onBehalfOf: AddressLike,
        referralCode: BigNumberish
    ], [
        void
    ], "nonpayable">;
    withdraw: TypedContractMethod<[
        asset: AddressLike,
        amount: BigNumberish,
        to: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getReserveData"): TypedContractMethod<[
        asset: AddressLike
    ], [
        IAaveV3Pool.ReserveDataStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getReserveNormalizedIncome"): TypedContractMethod<[underlyingAsset: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "supply"): TypedContractMethod<[
        asset: AddressLike,
        amount: BigNumberish,
        onBehalfOf: AddressLike,
        referralCode: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "withdraw"): TypedContractMethod<[
        asset: AddressLike,
        amount: BigNumberish,
        to: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    filters: {};
}
