import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export declare namespace IInfraredVault {
    type UserRewardStruct = {
        token: AddressLike;
        amount: BigNumberish;
    };
    type UserRewardStructOutput = [token: string, amount: bigint] & {
        token: string;
        amount: bigint;
    };
}
export interface IInfraredVaultInterface extends Interface {
    getFunction(nameOrSignature: "earned" | "getAllRewardTokens" | "getAllRewardsForUser" | "getRewardForUser" | "stake" | "stakingToken" | "withdraw"): FunctionFragment;
    encodeFunctionData(functionFragment: "earned", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "getAllRewardTokens", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAllRewardsForUser", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getRewardForUser", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "stake", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "stakingToken", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdraw", values: [BigNumberish]): string;
    decodeFunctionResult(functionFragment: "earned", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllRewardTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllRewardsForUser", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardForUser", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stakingToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
}
export interface IInfraredVault extends BaseContract {
    connect(runner?: ContractRunner | null): IInfraredVault;
    waitForDeployment(): Promise<this>;
    interface: IInfraredVaultInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    earned: TypedContractMethod<[
        account: AddressLike,
        rewardToken: AddressLike
    ], [
        bigint
    ], "view">;
    getAllRewardTokens: TypedContractMethod<[], [string[]], "view">;
    getAllRewardsForUser: TypedContractMethod<[
        _user: AddressLike
    ], [
        IInfraredVault.UserRewardStructOutput[]
    ], "view">;
    getRewardForUser: TypedContractMethod<[
        _user: AddressLike
    ], [
        void
    ], "nonpayable">;
    stake: TypedContractMethod<[amount: BigNumberish], [void], "nonpayable">;
    stakingToken: TypedContractMethod<[], [string], "view">;
    withdraw: TypedContractMethod<[amount: BigNumberish], [void], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "earned"): TypedContractMethod<[
        account: AddressLike,
        rewardToken: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "getAllRewardTokens"): TypedContractMethod<[], [string[]], "view">;
    getFunction(nameOrSignature: "getAllRewardsForUser"): TypedContractMethod<[
        _user: AddressLike
    ], [
        IInfraredVault.UserRewardStructOutput[]
    ], "view">;
    getFunction(nameOrSignature: "getRewardForUser"): TypedContractMethod<[_user: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "stake"): TypedContractMethod<[amount: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "stakingToken"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "withdraw"): TypedContractMethod<[amount: BigNumberish], [void], "nonpayable">;
    filters: {};
}
