import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface IMultiRewardsInterface extends Interface {
    getFunction(nameOrSignature: "balanceOf" | "earned" | "exit" | "getReward" | "getRewardForDuration" | "lastTimeRewardApplicable" | "rewardData" | "rewardPerToken" | "rewardTokens" | "totalSupply"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "Recovered" | "RewardAdded" | "RewardPaid" | "RewardStored" | "RewardsDistributorUpdated" | "RewardsDurationUpdated" | "Staked" | "Withdrawn"): EventFragment;
    encodeFunctionData(functionFragment: "balanceOf", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "earned", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "exit", values?: undefined): string;
    encodeFunctionData(functionFragment: "getReward", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRewardForDuration", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "lastTimeRewardApplicable", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "rewardData", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "rewardPerToken", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "rewardTokens", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "earned", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getReward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardForDuration", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lastTimeRewardApplicable", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardPerToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
}
export declare namespace RecoveredEvent {
    type InputTuple = [token: AddressLike, amount: BigNumberish];
    type OutputTuple = [token: string, amount: bigint];
    interface OutputObject {
        token: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RewardAddedEvent {
    type InputTuple = [rewardsToken: AddressLike, reward: BigNumberish];
    type OutputTuple = [rewardsToken: string, reward: bigint];
    interface OutputObject {
        rewardsToken: string;
        reward: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RewardPaidEvent {
    type InputTuple = [
        user: AddressLike,
        rewardsToken: AddressLike,
        reward: BigNumberish
    ];
    type OutputTuple = [
        user: string,
        rewardsToken: string,
        reward: bigint
    ];
    interface OutputObject {
        user: string;
        rewardsToken: string;
        reward: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RewardStoredEvent {
    type InputTuple = [
        rewardsToken: AddressLike,
        rewardsDuration: BigNumberish
    ];
    type OutputTuple = [rewardsToken: string, rewardsDuration: bigint];
    interface OutputObject {
        rewardsToken: string;
        rewardsDuration: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RewardsDistributorUpdatedEvent {
    type InputTuple = [
        rewardsToken: AddressLike,
        newDistributor: AddressLike
    ];
    type OutputTuple = [rewardsToken: string, newDistributor: string];
    interface OutputObject {
        rewardsToken: string;
        newDistributor: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RewardsDurationUpdatedEvent {
    type InputTuple = [token: AddressLike, newDuration: BigNumberish];
    type OutputTuple = [token: string, newDuration: bigint];
    interface OutputObject {
        token: string;
        newDuration: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace StakedEvent {
    type InputTuple = [user: AddressLike, amount: BigNumberish];
    type OutputTuple = [user: string, amount: bigint];
    interface OutputObject {
        user: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace WithdrawnEvent {
    type InputTuple = [user: AddressLike, amount: BigNumberish];
    type OutputTuple = [user: string, amount: bigint];
    interface OutputObject {
        user: string;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface IMultiRewards extends BaseContract {
    connect(runner?: ContractRunner | null): IMultiRewards;
    waitForDeployment(): Promise<this>;
    interface: IMultiRewardsInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    balanceOf: TypedContractMethod<[account: AddressLike], [bigint], "view">;
    earned: TypedContractMethod<[
        account: AddressLike,
        _rewardsToken: AddressLike
    ], [
        bigint
    ], "view">;
    exit: TypedContractMethod<[], [void], "nonpayable">;
    getReward: TypedContractMethod<[], [void], "nonpayable">;
    getRewardForDuration: TypedContractMethod<[
        _rewardsToken: AddressLike
    ], [
        bigint
    ], "view">;
    lastTimeRewardApplicable: TypedContractMethod<[
        _rewardsToken: AddressLike
    ], [
        bigint
    ], "view">;
    rewardData: TypedContractMethod<[
        _rewardsToken: AddressLike
    ], [
        [
            string,
            bigint,
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            rewardsDistributor: string;
            rewardsDuration: bigint;
            periodFinish: bigint;
            rewardRate: bigint;
            lastUpdateTime: bigint;
            rewardPerTokenStored: bigint;
            rewardResidual: bigint;
        }
    ], "view">;
    rewardPerToken: TypedContractMethod<[
        _rewardsToken: AddressLike
    ], [
        bigint
    ], "view">;
    rewardTokens: TypedContractMethod<[index: BigNumberish], [string], "view">;
    totalSupply: TypedContractMethod<[], [bigint], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "balanceOf"): TypedContractMethod<[account: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "earned"): TypedContractMethod<[
        account: AddressLike,
        _rewardsToken: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "exit"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "getReward"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "getRewardForDuration"): TypedContractMethod<[_rewardsToken: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "lastTimeRewardApplicable"): TypedContractMethod<[_rewardsToken: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "rewardData"): TypedContractMethod<[
        _rewardsToken: AddressLike
    ], [
        [
            string,
            bigint,
            bigint,
            bigint,
            bigint,
            bigint,
            bigint
        ] & {
            rewardsDistributor: string;
            rewardsDuration: bigint;
            periodFinish: bigint;
            rewardRate: bigint;
            lastUpdateTime: bigint;
            rewardPerTokenStored: bigint;
            rewardResidual: bigint;
        }
    ], "view">;
    getFunction(nameOrSignature: "rewardPerToken"): TypedContractMethod<[_rewardsToken: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "rewardTokens"): TypedContractMethod<[index: BigNumberish], [string], "view">;
    getFunction(nameOrSignature: "totalSupply"): TypedContractMethod<[], [bigint], "view">;
    getEvent(key: "Recovered"): TypedContractEvent<RecoveredEvent.InputTuple, RecoveredEvent.OutputTuple, RecoveredEvent.OutputObject>;
    getEvent(key: "RewardAdded"): TypedContractEvent<RewardAddedEvent.InputTuple, RewardAddedEvent.OutputTuple, RewardAddedEvent.OutputObject>;
    getEvent(key: "RewardPaid"): TypedContractEvent<RewardPaidEvent.InputTuple, RewardPaidEvent.OutputTuple, RewardPaidEvent.OutputObject>;
    getEvent(key: "RewardStored"): TypedContractEvent<RewardStoredEvent.InputTuple, RewardStoredEvent.OutputTuple, RewardStoredEvent.OutputObject>;
    getEvent(key: "RewardsDistributorUpdated"): TypedContractEvent<RewardsDistributorUpdatedEvent.InputTuple, RewardsDistributorUpdatedEvent.OutputTuple, RewardsDistributorUpdatedEvent.OutputObject>;
    getEvent(key: "RewardsDurationUpdated"): TypedContractEvent<RewardsDurationUpdatedEvent.InputTuple, RewardsDurationUpdatedEvent.OutputTuple, RewardsDurationUpdatedEvent.OutputObject>;
    getEvent(key: "Staked"): TypedContractEvent<StakedEvent.InputTuple, StakedEvent.OutputTuple, StakedEvent.OutputObject>;
    getEvent(key: "Withdrawn"): TypedContractEvent<WithdrawnEvent.InputTuple, WithdrawnEvent.OutputTuple, WithdrawnEvent.OutputObject>;
    filters: {
        "Recovered(address,uint256)": TypedContractEvent<RecoveredEvent.InputTuple, RecoveredEvent.OutputTuple, RecoveredEvent.OutputObject>;
        Recovered: TypedContractEvent<RecoveredEvent.InputTuple, RecoveredEvent.OutputTuple, RecoveredEvent.OutputObject>;
        "RewardAdded(address,uint256)": TypedContractEvent<RewardAddedEvent.InputTuple, RewardAddedEvent.OutputTuple, RewardAddedEvent.OutputObject>;
        RewardAdded: TypedContractEvent<RewardAddedEvent.InputTuple, RewardAddedEvent.OutputTuple, RewardAddedEvent.OutputObject>;
        "RewardPaid(address,address,uint256)": TypedContractEvent<RewardPaidEvent.InputTuple, RewardPaidEvent.OutputTuple, RewardPaidEvent.OutputObject>;
        RewardPaid: TypedContractEvent<RewardPaidEvent.InputTuple, RewardPaidEvent.OutputTuple, RewardPaidEvent.OutputObject>;
        "RewardStored(address,uint256)": TypedContractEvent<RewardStoredEvent.InputTuple, RewardStoredEvent.OutputTuple, RewardStoredEvent.OutputObject>;
        RewardStored: TypedContractEvent<RewardStoredEvent.InputTuple, RewardStoredEvent.OutputTuple, RewardStoredEvent.OutputObject>;
        "RewardsDistributorUpdated(address,address)": TypedContractEvent<RewardsDistributorUpdatedEvent.InputTuple, RewardsDistributorUpdatedEvent.OutputTuple, RewardsDistributorUpdatedEvent.OutputObject>;
        RewardsDistributorUpdated: TypedContractEvent<RewardsDistributorUpdatedEvent.InputTuple, RewardsDistributorUpdatedEvent.OutputTuple, RewardsDistributorUpdatedEvent.OutputObject>;
        "RewardsDurationUpdated(address,uint256)": TypedContractEvent<RewardsDurationUpdatedEvent.InputTuple, RewardsDurationUpdatedEvent.OutputTuple, RewardsDurationUpdatedEvent.OutputObject>;
        RewardsDurationUpdated: TypedContractEvent<RewardsDurationUpdatedEvent.InputTuple, RewardsDurationUpdatedEvent.OutputTuple, RewardsDurationUpdatedEvent.OutputObject>;
        "Staked(address,uint256)": TypedContractEvent<StakedEvent.InputTuple, StakedEvent.OutputTuple, StakedEvent.OutputObject>;
        Staked: TypedContractEvent<StakedEvent.InputTuple, StakedEvent.OutputTuple, StakedEvent.OutputObject>;
        "Withdrawn(address,uint256)": TypedContractEvent<WithdrawnEvent.InputTuple, WithdrawnEvent.OutputTuple, WithdrawnEvent.OutputObject>;
        Withdrawn: TypedContractEvent<WithdrawnEvent.InputTuple, WithdrawnEvent.OutputTuple, WithdrawnEvent.OutputObject>;
    };
}
