import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../common";
export interface SuTokenRateModelInterface extends Interface {
    getFunction(nameOrSignature: "borrowRate" | "changeOwner" | "getBorrowRate" | "getSupplyRate" | "isInterestRateModel" | "owner" | "setBorrowRate" | "setSupplyRate" | "supplyRate"): FunctionFragment;
    encodeFunctionData(functionFragment: "borrowRate", values?: undefined): string;
    encodeFunctionData(functionFragment: "changeOwner", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getBorrowRate", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getSupplyRate", values: [BigNumberish, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "isInterestRateModel", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "setBorrowRate", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setSupplyRate", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "supplyRate", values?: undefined): string;
    decodeFunctionResult(functionFragment: "borrowRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "changeOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getBorrowRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getSupplyRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInterestRateModel", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setBorrowRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setSupplyRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supplyRate", data: BytesLike): Result;
}
export interface SuTokenRateModel extends BaseContract {
    connect(runner?: ContractRunner | null): SuTokenRateModel;
    waitForDeployment(): Promise<this>;
    interface: SuTokenRateModelInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    borrowRate: TypedContractMethod<[], [bigint], "view">;
    changeOwner: TypedContractMethod<[owner_: AddressLike], [void], "nonpayable">;
    getBorrowRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getSupplyRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    isInterestRateModel: TypedContractMethod<[], [boolean], "view">;
    owner: TypedContractMethod<[], [string], "view">;
    setBorrowRate: TypedContractMethod<[
        rate: BigNumberish
    ], [
        void
    ], "nonpayable">;
    setSupplyRate: TypedContractMethod<[
        rate: BigNumberish
    ], [
        void
    ], "nonpayable">;
    supplyRate: TypedContractMethod<[], [bigint], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "borrowRate"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "changeOwner"): TypedContractMethod<[owner_: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "getBorrowRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "getSupplyRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "isInterestRateModel"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "owner"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "setBorrowRate"): TypedContractMethod<[rate: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "setSupplyRate"): TypedContractMethod<[rate: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "supplyRate"): TypedContractMethod<[], [bigint], "view">;
    filters: {};
}
