import type { BaseContract, BytesLike, FunctionFragment, Result, Interface, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../common";
export interface IBalancerVaultInterface extends Interface {
    getFunction(nameOrSignature: "getPoolTokens"): FunctionFragment;
    encodeFunctionData(functionFragment: "getPoolTokens", values: [BytesLike]): string;
    decodeFunctionResult(functionFragment: "getPoolTokens", data: BytesLike): Result;
}
export interface IBalancerVault extends BaseContract {
    connect(runner?: ContractRunner | null): IBalancerVault;
    waitForDeployment(): Promise<this>;
    interface: IBalancerVaultInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getPoolTokens: TypedContractMethod<[
        poolId: BytesLike
    ], [
        [
            string[],
            bigint[],
            bigint
        ] & {
            tokens: string[];
            balances: bigint[];
            lastChangeBlock: bigint;
        }
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getPoolTokens"): TypedContractMethod<[
        poolId: BytesLike
    ], [
        [
            string[],
            bigint[],
            bigint
        ] & {
            tokens: string[];
            balances: bigint[];
            lastChangeBlock: bigint;
        }
    ], "view">;
    filters: {};
}
