import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface ICTokenInterface extends Interface {
    getFunction(nameOrSignature: "_acceptAdmin" | "_reduceReserves" | "_setComptroller" | "_setDiscountRate" | "_setInterestRateModel" | "_setPendingAdmin" | "_setReserveFactor" | "accrualBlockTimestamp" | "accrueInterest" | "allowance" | "approve" | "balanceOf" | "balanceOfUnderlying" | "borrowBalanceCurrent" | "borrowBalanceStored" | "borrowRatePerBlock" | "exchangeRateCurrent" | "exchangeRateStored" | "getAccountSnapshot" | "getCash" | "seize" | "supplyRatePerBlock" | "totalBorrowsCurrent" | "totalSupply" | "transfer" | "transferFrom"): FunctionFragment;
    encodeFunctionData(functionFragment: "_acceptAdmin", values?: undefined): string;
    encodeFunctionData(functionFragment: "_reduceReserves", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "_setComptroller", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setDiscountRate", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "_setInterestRateModel", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setPendingAdmin", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "_setReserveFactor", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "accrualBlockTimestamp", values?: undefined): string;
    encodeFunctionData(functionFragment: "accrueInterest", values?: undefined): string;
    encodeFunctionData(functionFragment: "allowance", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "approve", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "balanceOfUnderlying", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowBalanceCurrent", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowBalanceStored", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "borrowRatePerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "exchangeRateCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "exchangeRateStored", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAccountSnapshot", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getCash", values?: undefined): string;
    encodeFunctionData(functionFragment: "seize", values: [
        AddressLike,
        AddressLike,
        BigNumberish,
        BigNumberish,
        boolean,
        BigNumberish
    ]): string;
    encodeFunctionData(functionFragment: "supplyRatePerBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalBorrowsCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transfer", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [AddressLike, AddressLike, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "_acceptAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_reduceReserves", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setComptroller", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setDiscountRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setInterestRateModel", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setPendingAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_setReserveFactor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "accrualBlockTimestamp", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "accrueInterest", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOfUnderlying", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowBalanceCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowBalanceStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "borrowRatePerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exchangeRateCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exchangeRateStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAccountSnapshot", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCash", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "seize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supplyRatePerBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalBorrowsCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
}
export interface ICToken extends BaseContract {
    connect(runner?: ContractRunner | null): ICToken;
    waitForDeployment(): Promise<this>;
    interface: ICTokenInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    _acceptAdmin: TypedContractMethod<[], [void], "nonpayable">;
    _reduceReserves: TypedContractMethod<[
        reduceAmount: BigNumberish
    ], [
        void
    ], "nonpayable">;
    _setComptroller: TypedContractMethod<[
        newComptroller: AddressLike
    ], [
        void
    ], "nonpayable">;
    _setDiscountRate: TypedContractMethod<[
        discountRateMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    _setInterestRateModel: TypedContractMethod<[
        newInterestRateModel: AddressLike
    ], [
        void
    ], "nonpayable">;
    _setPendingAdmin: TypedContractMethod<[
        newPendingAdmin: AddressLike
    ], [
        void
    ], "nonpayable">;
    _setReserveFactor: TypedContractMethod<[
        newReserveFactorMantissa: BigNumberish
    ], [
        void
    ], "nonpayable">;
    accrualBlockTimestamp: TypedContractMethod<[], [bigint], "nonpayable">;
    accrueInterest: TypedContractMethod<[], [void], "nonpayable">;
    allowance: TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    approve: TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    balanceOf: TypedContractMethod<[owner: AddressLike], [bigint], "view">;
    balanceOfUnderlying: TypedContractMethod<[
        owner: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    borrowBalanceCurrent: TypedContractMethod<[
        account: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    borrowBalanceStored: TypedContractMethod<[
        account: AddressLike
    ], [
        bigint
    ], "view">;
    borrowRatePerBlock: TypedContractMethod<[], [bigint], "view">;
    exchangeRateCurrent: TypedContractMethod<[], [bigint], "nonpayable">;
    exchangeRateStored: TypedContractMethod<[], [bigint], "view">;
    getAccountSnapshot: TypedContractMethod<[
        account: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "view">;
    getCash: TypedContractMethod<[], [bigint], "view">;
    seize: TypedContractMethod<[
        liquidator: AddressLike,
        borrower: AddressLike,
        seizeTokens: BigNumberish,
        seizeProfitTokens: BigNumberish,
        isRedemption: boolean,
        redemptionRateMantissa: BigNumberish
    ], [
        void
    ], "nonpayable">;
    supplyRatePerBlock: TypedContractMethod<[], [bigint], "view">;
    totalBorrowsCurrent: TypedContractMethod<[], [bigint], "nonpayable">;
    totalSupply: TypedContractMethod<[], [bigint], "view">;
    transfer: TypedContractMethod<[
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    transferFrom: TypedContractMethod<[
        src: AddressLike,
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "_acceptAdmin"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "_reduceReserves"): TypedContractMethod<[reduceAmount: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "_setComptroller"): TypedContractMethod<[newComptroller: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "_setDiscountRate"): TypedContractMethod<[
        discountRateMantissa: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "_setInterestRateModel"): TypedContractMethod<[
        newInterestRateModel: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "_setPendingAdmin"): TypedContractMethod<[newPendingAdmin: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "_setReserveFactor"): TypedContractMethod<[
        newReserveFactorMantissa: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "accrualBlockTimestamp"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "accrueInterest"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "allowance"): TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "approve"): TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "balanceOf"): TypedContractMethod<[owner: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "balanceOfUnderlying"): TypedContractMethod<[owner: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "borrowBalanceCurrent"): TypedContractMethod<[account: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "borrowBalanceStored"): TypedContractMethod<[account: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "borrowRatePerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "exchangeRateCurrent"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "exchangeRateStored"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "getAccountSnapshot"): TypedContractMethod<[
        account: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "view">;
    getFunction(nameOrSignature: "getCash"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "seize"): TypedContractMethod<[
        liquidator: AddressLike,
        borrower: AddressLike,
        seizeTokens: BigNumberish,
        seizeProfitTokens: BigNumberish,
        isRedemption: boolean,
        redemptionRateMantissa: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "supplyRatePerBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "totalBorrowsCurrent"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "totalSupply"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "transfer"): TypedContractMethod<[
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "transferFrom"): TypedContractMethod<[
        src: AddressLike,
        dst: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    filters: {};
}
