import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export declare namespace IGovernorBravo {
    type ReceiptStruct = {
        hasVoted: boolean;
        support: BigNumberish;
        votes: BigNumberish;
    };
    type ReceiptStructOutput = [
        hasVoted: boolean,
        support: bigint,
        votes: bigint
    ] & {
        hasVoted: boolean;
        support: bigint;
        votes: bigint;
    };
    type ProposalStruct = {
        id: BigNumberish;
        proposer: AddressLike;
        eta: BigNumberish;
        startBlock: BigNumberish;
        endBlock: BigNumberish;
        forVotes: BigNumberish;
        againstVotes: BigNumberish;
        abstainVotes: BigNumberish;
        canceled: boolean;
        executed: boolean;
    };
    type ProposalStructOutput = [
        id: bigint,
        proposer: string,
        eta: bigint,
        startBlock: bigint,
        endBlock: bigint,
        forVotes: bigint,
        againstVotes: bigint,
        abstainVotes: bigint,
        canceled: boolean,
        executed: boolean
    ] & {
        id: bigint;
        proposer: string;
        eta: bigint;
        startBlock: bigint;
        endBlock: bigint;
        forVotes: bigint;
        againstVotes: bigint;
        abstainVotes: bigint;
        canceled: boolean;
        executed: boolean;
    };
}
export interface IGovernorBravoInterface extends Interface {
    getFunction(nameOrSignature: "getActions" | "getReceipt" | "proposals"): FunctionFragment;
    encodeFunctionData(functionFragment: "getActions", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getReceipt", values: [BigNumberish, AddressLike]): string;
    encodeFunctionData(functionFragment: "proposals", values: [BigNumberish]): string;
    decodeFunctionResult(functionFragment: "getActions", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getReceipt", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "proposals", data: BytesLike): Result;
}
export interface IGovernorBravo extends BaseContract {
    connect(runner?: ContractRunner | null): IGovernorBravo;
    waitForDeployment(): Promise<this>;
    interface: IGovernorBravoInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getActions: TypedContractMethod<[
        proposalId: BigNumberish
    ], [
        [
            string[],
            bigint[],
            string[],
            string[]
        ] & {
            targets: string[];
            values: bigint[];
            signatures: string[];
            calldatas: string[];
        }
    ], "view">;
    getReceipt: TypedContractMethod<[
        proposalId: BigNumberish,
        voter: AddressLike
    ], [
        IGovernorBravo.ReceiptStructOutput
    ], "view">;
    proposals: TypedContractMethod<[
        proposalId: BigNumberish
    ], [
        IGovernorBravo.ProposalStructOutput
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getActions"): TypedContractMethod<[
        proposalId: BigNumberish
    ], [
        [
            string[],
            bigint[],
            string[],
            string[]
        ] & {
            targets: string[];
            values: bigint[];
            signatures: string[];
            calldatas: string[];
        }
    ], "view">;
    getFunction(nameOrSignature: "getReceipt"): TypedContractMethod<[
        proposalId: BigNumberish,
        voter: AddressLike
    ], [
        IGovernorBravo.ReceiptStructOutput
    ], "view">;
    getFunction(nameOrSignature: "proposals"): TypedContractMethod<[
        proposalId: BigNumberish
    ], [
        IGovernorBravo.ProposalStructOutput
    ], "view">;
    filters: {};
}
