import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface IInterestRateModelInterface extends Interface {
    getFunction(nameOrSignature: "getBorrowRate" | "getSupplyRate" | "isInterestRateModel" | "secondsPerYear"): FunctionFragment;
    encodeFunctionData(functionFragment: "getBorrowRate", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getSupplyRate", values: [BigNumberish, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "isInterestRateModel", values?: undefined): string;
    encodeFunctionData(functionFragment: "secondsPerYear", values?: undefined): string;
    decodeFunctionResult(functionFragment: "getBorrowRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getSupplyRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isInterestRateModel", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "secondsPerYear", data: BytesLike): Result;
}
export interface IInterestRateModel extends BaseContract {
    connect(runner?: ContractRunner | null): IInterestRateModel;
    waitForDeployment(): Promise<this>;
    interface: IInterestRateModelInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getBorrowRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getSupplyRate: TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    isInterestRateModel: TypedContractMethod<[], [boolean], "view">;
    secondsPerYear: TypedContractMethod<[], [bigint], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getBorrowRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "getSupplyRate"): TypedContractMethod<[
        cash: BigNumberish,
        borrows: BigNumberish,
        reserves: BigNumberish,
        reserveFactorMantissa: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "isInterestRateModel"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "secondsPerYear"): TypedContractMethod<[], [bigint], "view">;
    filters: {};
}
