import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface IPYieldTokenInterface extends Interface {
    getFunction(nameOrSignature: "PT" | "SY" | "allowance" | "approve" | "balanceOf" | "decimals" | "doCacheIndexSameBlock" | "expiry" | "factory" | "getRewardTokens" | "isExpired" | "mintPY" | "name" | "pyIndexCurrent" | "pyIndexLastUpdatedBlock" | "pyIndexStored" | "redeemDueInterestAndRewards" | "redeemPY" | "redeemPYMulti" | "rewardIndexesCurrent" | "symbol" | "totalSupply" | "transfer" | "transferFrom"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "Approval" | "Burn" | "CollectRewardFee" | "Mint" | "NewInterestIndex" | "RedeemInterest" | "RedeemRewards" | "Transfer"): EventFragment;
    encodeFunctionData(functionFragment: "PT", values?: undefined): string;
    encodeFunctionData(functionFragment: "SY", values?: undefined): string;
    encodeFunctionData(functionFragment: "allowance", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "approve", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "decimals", values?: undefined): string;
    encodeFunctionData(functionFragment: "doCacheIndexSameBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "expiry", values?: undefined): string;
    encodeFunctionData(functionFragment: "factory", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRewardTokens", values?: undefined): string;
    encodeFunctionData(functionFragment: "isExpired", values?: undefined): string;
    encodeFunctionData(functionFragment: "mintPY", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "name", values?: undefined): string;
    encodeFunctionData(functionFragment: "pyIndexCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "pyIndexLastUpdatedBlock", values?: undefined): string;
    encodeFunctionData(functionFragment: "pyIndexStored", values?: undefined): string;
    encodeFunctionData(functionFragment: "redeemDueInterestAndRewards", values: [AddressLike, boolean, boolean]): string;
    encodeFunctionData(functionFragment: "redeemPY", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "redeemPYMulti", values: [AddressLike[], BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "rewardIndexesCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "symbol", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transfer", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [AddressLike, AddressLike, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "PT", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "SY", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "decimals", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "doCacheIndexSameBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "expiry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "factory", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isExpired", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mintPY", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "name", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pyIndexCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pyIndexLastUpdatedBlock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pyIndexStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemDueInterestAndRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemPY", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemPYMulti", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardIndexesCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "symbol", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
}
export declare namespace ApprovalEvent {
    type InputTuple = [
        owner: AddressLike,
        spender: AddressLike,
        value: BigNumberish
    ];
    type OutputTuple = [owner: string, spender: string, value: bigint];
    interface OutputObject {
        owner: string;
        spender: string;
        value: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace BurnEvent {
    type InputTuple = [
        caller: AddressLike,
        receiver: AddressLike,
        amountPYToRedeem: BigNumberish,
        amountSyOut: BigNumberish
    ];
    type OutputTuple = [
        caller: string,
        receiver: string,
        amountPYToRedeem: bigint,
        amountSyOut: bigint
    ];
    interface OutputObject {
        caller: string;
        receiver: string;
        amountPYToRedeem: bigint;
        amountSyOut: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace CollectRewardFeeEvent {
    type InputTuple = [
        rewardToken: AddressLike,
        amountRewardFee: BigNumberish
    ];
    type OutputTuple = [rewardToken: string, amountRewardFee: bigint];
    interface OutputObject {
        rewardToken: string;
        amountRewardFee: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace MintEvent {
    type InputTuple = [
        caller: AddressLike,
        receiverPT: AddressLike,
        receiverYT: AddressLike,
        amountSyToMint: BigNumberish,
        amountPYOut: BigNumberish
    ];
    type OutputTuple = [
        caller: string,
        receiverPT: string,
        receiverYT: string,
        amountSyToMint: bigint,
        amountPYOut: bigint
    ];
    interface OutputObject {
        caller: string;
        receiverPT: string;
        receiverYT: string;
        amountSyToMint: bigint;
        amountPYOut: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace NewInterestIndexEvent {
    type InputTuple = [newIndex: BigNumberish];
    type OutputTuple = [newIndex: bigint];
    interface OutputObject {
        newIndex: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RedeemInterestEvent {
    type InputTuple = [user: AddressLike, interestOut: BigNumberish];
    type OutputTuple = [user: string, interestOut: bigint];
    interface OutputObject {
        user: string;
        interestOut: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RedeemRewardsEvent {
    type InputTuple = [
        user: AddressLike,
        amountRewardsOut: BigNumberish[]
    ];
    type OutputTuple = [user: string, amountRewardsOut: bigint[]];
    interface OutputObject {
        user: string;
        amountRewardsOut: bigint[];
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace TransferEvent {
    type InputTuple = [
        from: AddressLike,
        to: AddressLike,
        value: BigNumberish
    ];
    type OutputTuple = [from: string, to: string, value: bigint];
    interface OutputObject {
        from: string;
        to: string;
        value: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface IPYieldToken extends BaseContract {
    connect(runner?: ContractRunner | null): IPYieldToken;
    waitForDeployment(): Promise<this>;
    interface: IPYieldTokenInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    PT: TypedContractMethod<[], [string], "view">;
    SY: TypedContractMethod<[], [string], "view">;
    allowance: TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    approve: TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    balanceOf: TypedContractMethod<[account: AddressLike], [bigint], "view">;
    decimals: TypedContractMethod<[], [bigint], "view">;
    doCacheIndexSameBlock: TypedContractMethod<[], [boolean], "view">;
    expiry: TypedContractMethod<[], [bigint], "view">;
    factory: TypedContractMethod<[], [string], "view">;
    getRewardTokens: TypedContractMethod<[], [string[]], "view">;
    isExpired: TypedContractMethod<[], [boolean], "view">;
    mintPY: TypedContractMethod<[
        receiverPT: AddressLike,
        receiverYT: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    name: TypedContractMethod<[], [string], "view">;
    pyIndexCurrent: TypedContractMethod<[], [bigint], "nonpayable">;
    pyIndexLastUpdatedBlock: TypedContractMethod<[], [bigint], "view">;
    pyIndexStored: TypedContractMethod<[], [bigint], "view">;
    redeemDueInterestAndRewards: TypedContractMethod<[
        user: AddressLike,
        redeemInterest: boolean,
        redeemRewards: boolean
    ], [
        [bigint, bigint[]] & {
            interestOut: bigint;
            rewardsOut: bigint[];
        }
    ], "nonpayable">;
    redeemPY: TypedContractMethod<[
        receiver: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    redeemPYMulti: TypedContractMethod<[
        receivers: AddressLike[],
        amountPYToRedeems: BigNumberish[]
    ], [
        bigint[]
    ], "nonpayable">;
    rewardIndexesCurrent: TypedContractMethod<[], [bigint[]], "nonpayable">;
    symbol: TypedContractMethod<[], [string], "view">;
    totalSupply: TypedContractMethod<[], [bigint], "view">;
    transfer: TypedContractMethod<[
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    transferFrom: TypedContractMethod<[
        from: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "PT"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "SY"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "allowance"): TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "approve"): TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "balanceOf"): TypedContractMethod<[account: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "decimals"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "doCacheIndexSameBlock"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "expiry"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "factory"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "getRewardTokens"): TypedContractMethod<[], [string[]], "view">;
    getFunction(nameOrSignature: "isExpired"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "mintPY"): TypedContractMethod<[
        receiverPT: AddressLike,
        receiverYT: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "name"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "pyIndexCurrent"): TypedContractMethod<[], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "pyIndexLastUpdatedBlock"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "pyIndexStored"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "redeemDueInterestAndRewards"): TypedContractMethod<[
        user: AddressLike,
        redeemInterest: boolean,
        redeemRewards: boolean
    ], [
        [bigint, bigint[]] & {
            interestOut: bigint;
            rewardsOut: bigint[];
        }
    ], "nonpayable">;
    getFunction(nameOrSignature: "redeemPY"): TypedContractMethod<[receiver: AddressLike], [bigint], "nonpayable">;
    getFunction(nameOrSignature: "redeemPYMulti"): TypedContractMethod<[
        receivers: AddressLike[],
        amountPYToRedeems: BigNumberish[]
    ], [
        bigint[]
    ], "nonpayable">;
    getFunction(nameOrSignature: "rewardIndexesCurrent"): TypedContractMethod<[], [bigint[]], "nonpayable">;
    getFunction(nameOrSignature: "symbol"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "totalSupply"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "transfer"): TypedContractMethod<[
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "transferFrom"): TypedContractMethod<[
        from: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getEvent(key: "Approval"): TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
    getEvent(key: "Burn"): TypedContractEvent<BurnEvent.InputTuple, BurnEvent.OutputTuple, BurnEvent.OutputObject>;
    getEvent(key: "CollectRewardFee"): TypedContractEvent<CollectRewardFeeEvent.InputTuple, CollectRewardFeeEvent.OutputTuple, CollectRewardFeeEvent.OutputObject>;
    getEvent(key: "Mint"): TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
    getEvent(key: "NewInterestIndex"): TypedContractEvent<NewInterestIndexEvent.InputTuple, NewInterestIndexEvent.OutputTuple, NewInterestIndexEvent.OutputObject>;
    getEvent(key: "RedeemInterest"): TypedContractEvent<RedeemInterestEvent.InputTuple, RedeemInterestEvent.OutputTuple, RedeemInterestEvent.OutputObject>;
    getEvent(key: "RedeemRewards"): TypedContractEvent<RedeemRewardsEvent.InputTuple, RedeemRewardsEvent.OutputTuple, RedeemRewardsEvent.OutputObject>;
    getEvent(key: "Transfer"): TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    filters: {
        "Approval(address,address,uint256)": TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        Approval: TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        "Burn(address,address,uint256,uint256)": TypedContractEvent<BurnEvent.InputTuple, BurnEvent.OutputTuple, BurnEvent.OutputObject>;
        Burn: TypedContractEvent<BurnEvent.InputTuple, BurnEvent.OutputTuple, BurnEvent.OutputObject>;
        "CollectRewardFee(address,uint256)": TypedContractEvent<CollectRewardFeeEvent.InputTuple, CollectRewardFeeEvent.OutputTuple, CollectRewardFeeEvent.OutputObject>;
        CollectRewardFee: TypedContractEvent<CollectRewardFeeEvent.InputTuple, CollectRewardFeeEvent.OutputTuple, CollectRewardFeeEvent.OutputObject>;
        "Mint(address,address,address,uint256,uint256)": TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
        Mint: TypedContractEvent<MintEvent.InputTuple, MintEvent.OutputTuple, MintEvent.OutputObject>;
        "NewInterestIndex(uint256)": TypedContractEvent<NewInterestIndexEvent.InputTuple, NewInterestIndexEvent.OutputTuple, NewInterestIndexEvent.OutputObject>;
        NewInterestIndex: TypedContractEvent<NewInterestIndexEvent.InputTuple, NewInterestIndexEvent.OutputTuple, NewInterestIndexEvent.OutputObject>;
        "RedeemInterest(address,uint256)": TypedContractEvent<RedeemInterestEvent.InputTuple, RedeemInterestEvent.OutputTuple, RedeemInterestEvent.OutputObject>;
        RedeemInterest: TypedContractEvent<RedeemInterestEvent.InputTuple, RedeemInterestEvent.OutputTuple, RedeemInterestEvent.OutputObject>;
        "RedeemRewards(address,uint256[])": TypedContractEvent<RedeemRewardsEvent.InputTuple, RedeemRewardsEvent.OutputTuple, RedeemRewardsEvent.OutputObject>;
        RedeemRewards: TypedContractEvent<RedeemRewardsEvent.InputTuple, RedeemRewardsEvent.OutputTuple, RedeemRewardsEvent.OutputObject>;
        "Transfer(address,address,uint256)": TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
        Transfer: TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    };
}
