import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface IPendlePtOracleInterface extends Interface {
    getFunction(nameOrSignature: "getOracleState" | "getPtToSyRate"): FunctionFragment;
    encodeFunctionData(functionFragment: "getOracleState", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPtToSyRate", values: [AddressLike, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "getOracleState", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPtToSyRate", data: BytesLike): Result;
}
export interface IPendlePtOracle extends BaseContract {
    connect(runner?: ContractRunner | null): IPendlePtOracle;
    waitForDeployment(): Promise<this>;
    interface: IPendlePtOracleInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getOracleState: TypedContractMethod<[
        market: AddressLike,
        duration: BigNumberish
    ], [
        [
            boolean,
            bigint,
            boolean
        ] & {
            increaseCardinalityRequired: boolean;
            cardinalityRequired: bigint;
            oldestObservationSatisfied: boolean;
        }
    ], "view">;
    getPtToSyRate: TypedContractMethod<[
        market: AddressLike,
        duration: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getOracleState"): TypedContractMethod<[
        market: AddressLike,
        duration: BigNumberish
    ], [
        [
            boolean,
            bigint,
            boolean
        ] & {
            increaseCardinalityRequired: boolean;
            cardinalityRequired: bigint;
            oldestObservationSatisfied: boolean;
        }
    ], "view">;
    getFunction(nameOrSignature: "getPtToSyRate"): TypedContractMethod<[
        market: AddressLike,
        duration: BigNumberish
    ], [
        bigint
    ], "view">;
    filters: {};
}
