import type { BaseContract, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface IPriceOracleInterface extends Interface {
    getFunction(nameOrSignature: "getUnderlyingPrice" | "getUnderlyingPriceNormalized"): FunctionFragment;
    encodeFunctionData(functionFragment: "getUnderlyingPrice", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getUnderlyingPriceNormalized", values: [AddressLike]): string;
    decodeFunctionResult(functionFragment: "getUnderlyingPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getUnderlyingPriceNormalized", data: BytesLike): Result;
}
export interface IPriceOracle extends BaseContract {
    connect(runner?: ContractRunner | null): IPriceOracle;
    waitForDeployment(): Promise<this>;
    interface: IPriceOracleInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getUnderlyingPrice: TypedContractMethod<[
        cToken: AddressLike
    ], [
        bigint
    ], "view">;
    getUnderlyingPriceNormalized: TypedContractMethod<[
        cToken_: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getUnderlyingPrice"): TypedContractMethod<[cToken: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "getUnderlyingPriceNormalized"): TypedContractMethod<[cToken_: AddressLike], [bigint], "view">;
    filters: {};
}
