import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface IRedemptionManagerInterface extends Interface {
    getFunction(nameOrSignature: "calcActualRepayAndSeize" | "getCurrentRedemptionRate" | "getRedemptionRate" | "redeemFaceValue" | "redeemFaceValueWithProviderPreview"): FunctionFragment;
    encodeFunctionData(functionFragment: "calcActualRepayAndSeize", values: [BigNumberish, AddressLike, AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "getCurrentRedemptionRate", values: [AddressLike, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getRedemptionRate", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "redeemFaceValue", values: [AddressLike, BigNumberish, AddressLike[], BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "redeemFaceValueWithProviderPreview", values: [
        AddressLike,
        AddressLike,
        AddressLike,
        AddressLike,
        BigNumberish,
        BigNumberish
    ]): string;
    decodeFunctionResult(functionFragment: "calcActualRepayAndSeize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCurrentRedemptionRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRedemptionRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemFaceValue", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeemFaceValueWithProviderPreview", data: BytesLike): Result;
}
export interface IRedemptionManager extends BaseContract {
    connect(runner?: ContractRunner | null): IRedemptionManager;
    waitForDeployment(): Promise<this>;
    interface: IRedemptionManagerInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    calcActualRepayAndSeize: TypedContractMethod<[
        redeemAmount: BigNumberish,
        provider: AddressLike,
        cToken: AddressLike,
        csuToken: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "nonpayable">;
    getCurrentRedemptionRate: TypedContractMethod<[
        asset: AddressLike,
        redeemAmount: BigNumberish,
        _totalSupply: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getRedemptionRate: TypedContractMethod<[
        asset: AddressLike
    ], [
        bigint
    ], "view">;
    redeemFaceValue: TypedContractMethod<[
        csuToken: AddressLike,
        amount: BigNumberish,
        providers: AddressLike[],
        deadline: BigNumberish,
        signature: BytesLike
    ], [
        void
    ], "nonpayable">;
    redeemFaceValueWithProviderPreview: TypedContractMethod<[
        redeemer: AddressLike,
        provider: AddressLike,
        cToken: AddressLike,
        csuToken: AddressLike,
        redeemAmount: BigNumberish,
        redemptionRateMantissa: BigNumberish
    ], [
        [bigint, bigint, bigint, bigint, bigint, bigint]
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "calcActualRepayAndSeize"): TypedContractMethod<[
        redeemAmount: BigNumberish,
        provider: AddressLike,
        cToken: AddressLike,
        csuToken: AddressLike
    ], [
        [bigint, bigint, bigint, bigint]
    ], "nonpayable">;
    getFunction(nameOrSignature: "getCurrentRedemptionRate"): TypedContractMethod<[
        asset: AddressLike,
        redeemAmount: BigNumberish,
        _totalSupply: BigNumberish
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "getRedemptionRate"): TypedContractMethod<[asset: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "redeemFaceValue"): TypedContractMethod<[
        csuToken: AddressLike,
        amount: BigNumberish,
        providers: AddressLike[],
        deadline: BigNumberish,
        signature: BytesLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "redeemFaceValueWithProviderPreview"): TypedContractMethod<[
        redeemer: AddressLike,
        provider: AddressLike,
        cToken: AddressLike,
        csuToken: AddressLike,
        redeemAmount: BigNumberish,
        redemptionRateMantissa: BigNumberish
    ], [
        [bigint, bigint, bigint, bigint, bigint, bigint]
    ], "nonpayable">;
    filters: {};
}
