import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface IStandardizedYieldInterface extends Interface {
    getFunction(nameOrSignature: "accruedRewards" | "allowance" | "approve" | "assetInfo" | "balanceOf" | "claimRewards" | "decimals" | "deposit" | "exchangeRate" | "getRewardTokens" | "getTokensIn" | "getTokensOut" | "isValidTokenIn" | "isValidTokenOut" | "name" | "previewDeposit" | "previewRedeem" | "redeem" | "rewardIndexesCurrent" | "rewardIndexesStored" | "symbol" | "totalSupply" | "transfer" | "transferFrom" | "yieldToken"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "Approval" | "ClaimRewards" | "Deposit" | "Redeem" | "Transfer"): EventFragment;
    encodeFunctionData(functionFragment: "accruedRewards", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "allowance", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "approve", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "assetInfo", values?: undefined): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "claimRewards", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "decimals", values?: undefined): string;
    encodeFunctionData(functionFragment: "deposit", values: [AddressLike, AddressLike, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "exchangeRate", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRewardTokens", values?: undefined): string;
    encodeFunctionData(functionFragment: "getTokensIn", values?: undefined): string;
    encodeFunctionData(functionFragment: "getTokensOut", values?: undefined): string;
    encodeFunctionData(functionFragment: "isValidTokenIn", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "isValidTokenOut", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "name", values?: undefined): string;
    encodeFunctionData(functionFragment: "previewDeposit", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "previewRedeem", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "redeem", values: [AddressLike, BigNumberish, AddressLike, BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "rewardIndexesCurrent", values?: undefined): string;
    encodeFunctionData(functionFragment: "rewardIndexesStored", values?: undefined): string;
    encodeFunctionData(functionFragment: "symbol", values?: undefined): string;
    encodeFunctionData(functionFragment: "totalSupply", values?: undefined): string;
    encodeFunctionData(functionFragment: "transfer", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferFrom", values: [AddressLike, AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "yieldToken", values?: undefined): string;
    decodeFunctionResult(functionFragment: "accruedRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "approve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "assetInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claimRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "decimals", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "exchangeRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRewardTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTokensIn", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTokensOut", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isValidTokenIn", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isValidTokenOut", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "name", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "previewDeposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "previewRedeem", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redeem", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardIndexesCurrent", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardIndexesStored", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "symbol", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalSupply", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transfer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferFrom", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "yieldToken", data: BytesLike): Result;
}
export declare namespace ApprovalEvent {
    type InputTuple = [
        owner: AddressLike,
        spender: AddressLike,
        value: BigNumberish
    ];
    type OutputTuple = [owner: string, spender: string, value: bigint];
    interface OutputObject {
        owner: string;
        spender: string;
        value: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace ClaimRewardsEvent {
    type InputTuple = [
        user: AddressLike,
        rewardTokens: AddressLike[],
        rewardAmounts: BigNumberish[]
    ];
    type OutputTuple = [
        user: string,
        rewardTokens: string[],
        rewardAmounts: bigint[]
    ];
    interface OutputObject {
        user: string;
        rewardTokens: string[];
        rewardAmounts: bigint[];
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace DepositEvent {
    type InputTuple = [
        caller: AddressLike,
        receiver: AddressLike,
        tokenIn: AddressLike,
        amountDeposited: BigNumberish,
        amountSyOut: BigNumberish
    ];
    type OutputTuple = [
        caller: string,
        receiver: string,
        tokenIn: string,
        amountDeposited: bigint,
        amountSyOut: bigint
    ];
    interface OutputObject {
        caller: string;
        receiver: string;
        tokenIn: string;
        amountDeposited: bigint;
        amountSyOut: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RedeemEvent {
    type InputTuple = [
        caller: AddressLike,
        receiver: AddressLike,
        tokenOut: AddressLike,
        amountSyToRedeem: BigNumberish,
        amountTokenOut: BigNumberish
    ];
    type OutputTuple = [
        caller: string,
        receiver: string,
        tokenOut: string,
        amountSyToRedeem: bigint,
        amountTokenOut: bigint
    ];
    interface OutputObject {
        caller: string;
        receiver: string;
        tokenOut: string;
        amountSyToRedeem: bigint;
        amountTokenOut: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace TransferEvent {
    type InputTuple = [
        from: AddressLike,
        to: AddressLike,
        value: BigNumberish
    ];
    type OutputTuple = [from: string, to: string, value: bigint];
    interface OutputObject {
        from: string;
        to: string;
        value: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface IStandardizedYield extends BaseContract {
    connect(runner?: ContractRunner | null): IStandardizedYield;
    waitForDeployment(): Promise<this>;
    interface: IStandardizedYieldInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    accruedRewards: TypedContractMethod<[user: AddressLike], [bigint[]], "view">;
    allowance: TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    approve: TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    assetInfo: TypedContractMethod<[
    ], [
        [
            bigint,
            string,
            bigint
        ] & {
            assetType: bigint;
            assetAddress: string;
            assetDecimals: bigint;
        }
    ], "view">;
    balanceOf: TypedContractMethod<[account: AddressLike], [bigint], "view">;
    claimRewards: TypedContractMethod<[
        user: AddressLike
    ], [
        bigint[]
    ], "nonpayable">;
    decimals: TypedContractMethod<[], [bigint], "view">;
    deposit: TypedContractMethod<[
        receiver: AddressLike,
        tokenIn: AddressLike,
        amountTokenToDeposit: BigNumberish,
        minSharesOut: BigNumberish
    ], [
        bigint
    ], "payable">;
    exchangeRate: TypedContractMethod<[], [bigint], "view">;
    getRewardTokens: TypedContractMethod<[], [string[]], "view">;
    getTokensIn: TypedContractMethod<[], [string[]], "view">;
    getTokensOut: TypedContractMethod<[], [string[]], "view">;
    isValidTokenIn: TypedContractMethod<[token: AddressLike], [boolean], "view">;
    isValidTokenOut: TypedContractMethod<[token: AddressLike], [boolean], "view">;
    name: TypedContractMethod<[], [string], "view">;
    previewDeposit: TypedContractMethod<[
        tokenIn: AddressLike,
        amountTokenToDeposit: BigNumberish
    ], [
        bigint
    ], "view">;
    previewRedeem: TypedContractMethod<[
        tokenOut: AddressLike,
        amountSharesToRedeem: BigNumberish
    ], [
        bigint
    ], "view">;
    redeem: TypedContractMethod<[
        receiver: AddressLike,
        amountSharesToRedeem: BigNumberish,
        tokenOut: AddressLike,
        minTokenOut: BigNumberish,
        burnFromInternalBalance: boolean
    ], [
        bigint
    ], "nonpayable">;
    rewardIndexesCurrent: TypedContractMethod<[], [bigint[]], "nonpayable">;
    rewardIndexesStored: TypedContractMethod<[], [bigint[]], "view">;
    symbol: TypedContractMethod<[], [string], "view">;
    totalSupply: TypedContractMethod<[], [bigint], "view">;
    transfer: TypedContractMethod<[
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    transferFrom: TypedContractMethod<[
        from: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    yieldToken: TypedContractMethod<[], [string], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "accruedRewards"): TypedContractMethod<[user: AddressLike], [bigint[]], "view">;
    getFunction(nameOrSignature: "allowance"): TypedContractMethod<[
        owner: AddressLike,
        spender: AddressLike
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "approve"): TypedContractMethod<[
        spender: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "assetInfo"): TypedContractMethod<[
    ], [
        [
            bigint,
            string,
            bigint
        ] & {
            assetType: bigint;
            assetAddress: string;
            assetDecimals: bigint;
        }
    ], "view">;
    getFunction(nameOrSignature: "balanceOf"): TypedContractMethod<[account: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "claimRewards"): TypedContractMethod<[user: AddressLike], [bigint[]], "nonpayable">;
    getFunction(nameOrSignature: "decimals"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "deposit"): TypedContractMethod<[
        receiver: AddressLike,
        tokenIn: AddressLike,
        amountTokenToDeposit: BigNumberish,
        minSharesOut: BigNumberish
    ], [
        bigint
    ], "payable">;
    getFunction(nameOrSignature: "exchangeRate"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "getRewardTokens"): TypedContractMethod<[], [string[]], "view">;
    getFunction(nameOrSignature: "getTokensIn"): TypedContractMethod<[], [string[]], "view">;
    getFunction(nameOrSignature: "getTokensOut"): TypedContractMethod<[], [string[]], "view">;
    getFunction(nameOrSignature: "isValidTokenIn"): TypedContractMethod<[token: AddressLike], [boolean], "view">;
    getFunction(nameOrSignature: "isValidTokenOut"): TypedContractMethod<[token: AddressLike], [boolean], "view">;
    getFunction(nameOrSignature: "name"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "previewDeposit"): TypedContractMethod<[
        tokenIn: AddressLike,
        amountTokenToDeposit: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "previewRedeem"): TypedContractMethod<[
        tokenOut: AddressLike,
        amountSharesToRedeem: BigNumberish
    ], [
        bigint
    ], "view">;
    getFunction(nameOrSignature: "redeem"): TypedContractMethod<[
        receiver: AddressLike,
        amountSharesToRedeem: BigNumberish,
        tokenOut: AddressLike,
        minTokenOut: BigNumberish,
        burnFromInternalBalance: boolean
    ], [
        bigint
    ], "nonpayable">;
    getFunction(nameOrSignature: "rewardIndexesCurrent"): TypedContractMethod<[], [bigint[]], "nonpayable">;
    getFunction(nameOrSignature: "rewardIndexesStored"): TypedContractMethod<[], [bigint[]], "view">;
    getFunction(nameOrSignature: "symbol"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "totalSupply"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "transfer"): TypedContractMethod<[
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "transferFrom"): TypedContractMethod<[
        from: AddressLike,
        to: AddressLike,
        amount: BigNumberish
    ], [
        boolean
    ], "nonpayable">;
    getFunction(nameOrSignature: "yieldToken"): TypedContractMethod<[], [string], "view">;
    getEvent(key: "Approval"): TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
    getEvent(key: "ClaimRewards"): TypedContractEvent<ClaimRewardsEvent.InputTuple, ClaimRewardsEvent.OutputTuple, ClaimRewardsEvent.OutputObject>;
    getEvent(key: "Deposit"): TypedContractEvent<DepositEvent.InputTuple, DepositEvent.OutputTuple, DepositEvent.OutputObject>;
    getEvent(key: "Redeem"): TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
    getEvent(key: "Transfer"): TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    filters: {
        "Approval(address,address,uint256)": TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        Approval: TypedContractEvent<ApprovalEvent.InputTuple, ApprovalEvent.OutputTuple, ApprovalEvent.OutputObject>;
        "ClaimRewards(address,address[],uint256[])": TypedContractEvent<ClaimRewardsEvent.InputTuple, ClaimRewardsEvent.OutputTuple, ClaimRewardsEvent.OutputObject>;
        ClaimRewards: TypedContractEvent<ClaimRewardsEvent.InputTuple, ClaimRewardsEvent.OutputTuple, ClaimRewardsEvent.OutputObject>;
        "Deposit(address,address,address,uint256,uint256)": TypedContractEvent<DepositEvent.InputTuple, DepositEvent.OutputTuple, DepositEvent.OutputObject>;
        Deposit: TypedContractEvent<DepositEvent.InputTuple, DepositEvent.OutputTuple, DepositEvent.OutputObject>;
        "Redeem(address,address,address,uint256,uint256)": TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
        Redeem: TypedContractEvent<RedeemEvent.InputTuple, RedeemEvent.OutputTuple, RedeemEvent.OutputObject>;
        "Transfer(address,address,uint256)": TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
        Transfer: TypedContractEvent<TransferEvent.InputTuple, TransferEvent.OutputTuple, TransferEvent.OutputObject>;
    };
}
