import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export interface ITimelockInterface extends Interface {
    getFunction(nameOrSignature: "consumeValue" | "createAgreement"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "AgreementClaimed" | "AgreementCreated" | "AgreementFrozen" | "RescueAgreement" | "TimeLockFrozen"): EventFragment;
    encodeFunctionData(functionFragment: "consumeValue", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "createAgreement", values: [BigNumberish, BigNumberish, AddressLike]): string;
    decodeFunctionResult(functionFragment: "consumeValue", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createAgreement", data: BytesLike): Result;
}
export declare namespace AgreementClaimedEvent {
    type InputTuple = [
        agreementId: BigNumberish,
        beneficiary: AddressLike,
        asset: AddressLike,
        actionType: BigNumberish,
        amount: BigNumberish
    ];
    type OutputTuple = [
        agreementId: bigint,
        beneficiary: string,
        asset: string,
        actionType: bigint,
        amount: bigint
    ];
    interface OutputObject {
        agreementId: bigint;
        beneficiary: string;
        asset: string;
        actionType: bigint;
        amount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace AgreementCreatedEvent {
    type InputTuple = [
        agreementId: BigNumberish,
        beneficiary: AddressLike,
        asset: AddressLike,
        actionType: BigNumberish,
        amount: BigNumberish,
        timestamp: BigNumberish
    ];
    type OutputTuple = [
        agreementId: bigint,
        beneficiary: string,
        asset: string,
        actionType: bigint,
        amount: bigint,
        timestamp: bigint
    ];
    interface OutputObject {
        agreementId: bigint;
        beneficiary: string;
        asset: string;
        actionType: bigint;
        amount: bigint;
        timestamp: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace AgreementFrozenEvent {
    type InputTuple = [agreementId: BigNumberish, value: boolean];
    type OutputTuple = [agreementId: bigint, value: boolean];
    interface OutputObject {
        agreementId: bigint;
        value: boolean;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace RescueAgreementEvent {
    type InputTuple = [
        agreementId: BigNumberish,
        underlyToken: AddressLike,
        to: AddressLike,
        underlyAmount: BigNumberish
    ];
    type OutputTuple = [
        agreementId: bigint,
        underlyToken: string,
        to: string,
        underlyAmount: bigint
    ];
    interface OutputObject {
        agreementId: bigint;
        underlyToken: string;
        to: string;
        underlyAmount: bigint;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace TimeLockFrozenEvent {
    type InputTuple = [value: boolean];
    type OutputTuple = [value: boolean];
    interface OutputObject {
        value: boolean;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface ITimelock extends BaseContract {
    connect(runner?: ContractRunner | null): ITimelock;
    waitForDeployment(): Promise<this>;
    interface: ITimelockInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    consumeValue: TypedContractMethod<[
        underlyAmount: BigNumberish
    ], [
        void
    ], "nonpayable">;
    createAgreement: TypedContractMethod<[
        actionType: BigNumberish,
        underlyAmount: BigNumberish,
        beneficiary: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "consumeValue"): TypedContractMethod<[underlyAmount: BigNumberish], [void], "nonpayable">;
    getFunction(nameOrSignature: "createAgreement"): TypedContractMethod<[
        actionType: BigNumberish,
        underlyAmount: BigNumberish,
        beneficiary: AddressLike
    ], [
        bigint
    ], "nonpayable">;
    getEvent(key: "AgreementClaimed"): TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
    getEvent(key: "AgreementCreated"): TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
    getEvent(key: "AgreementFrozen"): TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
    getEvent(key: "RescueAgreement"): TypedContractEvent<RescueAgreementEvent.InputTuple, RescueAgreementEvent.OutputTuple, RescueAgreementEvent.OutputObject>;
    getEvent(key: "TimeLockFrozen"): TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
    filters: {
        "AgreementClaimed(uint256,address,address,uint8,uint256)": TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
        AgreementClaimed: TypedContractEvent<AgreementClaimedEvent.InputTuple, AgreementClaimedEvent.OutputTuple, AgreementClaimedEvent.OutputObject>;
        "AgreementCreated(uint256,address,address,uint8,uint256,uint256)": TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
        AgreementCreated: TypedContractEvent<AgreementCreatedEvent.InputTuple, AgreementCreatedEvent.OutputTuple, AgreementCreatedEvent.OutputObject>;
        "AgreementFrozen(uint256,bool)": TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
        AgreementFrozen: TypedContractEvent<AgreementFrozenEvent.InputTuple, AgreementFrozenEvent.OutputTuple, AgreementFrozenEvent.OutputObject>;
        "RescueAgreement(uint256,address,address,uint256)": TypedContractEvent<RescueAgreementEvent.InputTuple, RescueAgreementEvent.OutputTuple, RescueAgreementEvent.OutputObject>;
        RescueAgreement: TypedContractEvent<RescueAgreementEvent.InputTuple, RescueAgreementEvent.OutputTuple, RescueAgreementEvent.OutputObject>;
        "TimeLockFrozen(bool)": TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
        TimeLockFrozen: TypedContractEvent<TimeLockFrozenEvent.InputTuple, TimeLockFrozenEvent.OutputTuple, TimeLockFrozenEvent.OutputObject>;
    };
}
