import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export declare namespace IVault {
    type UserBalanceOpStruct = {
        kind: BigNumberish;
        asset: AddressLike;
        amount: BigNumberish;
        sender: AddressLike;
        recipient: AddressLike;
    };
    type UserBalanceOpStructOutput = [
        kind: bigint,
        asset: string,
        amount: bigint,
        sender: string,
        recipient: string
    ] & {
        kind: bigint;
        asset: string;
        amount: bigint;
        sender: string;
        recipient: string;
    };
}
export interface IVaultInterface extends Interface {
    getFunction(nameOrSignature: "getPoolTokens" | "manageUserBalance"): FunctionFragment;
    encodeFunctionData(functionFragment: "getPoolTokens", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "manageUserBalance", values: [IVault.UserBalanceOpStruct[]]): string;
    decodeFunctionResult(functionFragment: "getPoolTokens", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "manageUserBalance", data: BytesLike): Result;
}
export interface IVault extends BaseContract {
    connect(runner?: ContractRunner | null): IVault;
    waitForDeployment(): Promise<this>;
    interface: IVaultInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getPoolTokens: TypedContractMethod<[
        poolId: BytesLike
    ], [
        [
            string[],
            bigint[],
            bigint
        ] & {
            tokens: string[];
            balances: bigint[];
            lastChangeBlock: bigint;
        }
    ], "view">;
    manageUserBalance: TypedContractMethod<[
        ops: IVault.UserBalanceOpStruct[]
    ], [
        void
    ], "payable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getPoolTokens"): TypedContractMethod<[
        poolId: BytesLike
    ], [
        [
            string[],
            bigint[],
            bigint
        ] & {
            tokens: string[];
            balances: bigint[];
            lastChangeBlock: bigint;
        }
    ], "view">;
    getFunction(nameOrSignature: "manageUserBalance"): TypedContractMethod<[
        ops: IVault.UserBalanceOpStruct[]
    ], [
        void
    ], "payable">;
    filters: {};
}
