import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, EventFragment, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedLogDescription, TypedListener, TypedContractMethod } from "../../common";
export declare namespace FeedPriceOracle {
    type FeedDataStruct = {
        feedId: BytesLike;
        source: BigNumberish;
        addr: AddressLike;
        feedDecimals: BigNumberish;
        name: string;
    };
    type FeedDataStructOutput = [
        feedId: string,
        source: bigint,
        addr: string,
        feedDecimals: bigint,
        name: string
    ] & {
        feedId: string;
        source: bigint;
        addr: string;
        feedDecimals: bigint;
        name: string;
    };
}
export interface FeedPriceOracleSafeInterface extends Interface {
    getFunction(nameOrSignature: "acceptOwnership" | "feeds" | "fixedPrices" | "getFeed" | "getFixedPrice" | "getUnderlyingPrice" | "getUnderlyingPrices" | "isPriceOracle" | "owner" | "pendingOwner" | "removeFeed" | "removeFixedPrice" | "renounceOwnership" | "setBandFeed" | "setChainlinkFeed" | "setFixedPrice" | "setLpFeed" | "setPythFeed" | "setPythValidTimePeriod" | "setWitnetFeed" | "transferOwnership" | "validTimePeriod"): FunctionFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferStarted" | "OwnershipTransferred" | "SetFeed"): EventFragment;
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "feeds", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "fixedPrices", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getFeed", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getFixedPrice", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getUnderlyingPrice", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "getUnderlyingPrices", values: [AddressLike[]]): string;
    encodeFunctionData(functionFragment: "isPriceOracle", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "pendingOwner", values?: undefined): string;
    encodeFunctionData(functionFragment: "removeFeed", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "removeFixedPrice", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setBandFeed", values: [AddressLike, AddressLike, BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "setChainlinkFeed", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "setFixedPrice", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setLpFeed", values: [AddressLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "setPythFeed", values: [AddressLike, BytesLike, AddressLike]): string;
    encodeFunctionData(functionFragment: "setPythValidTimePeriod", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setWitnetFeed", values: [AddressLike, AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "validTimePeriod", values?: undefined): string;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "feeds", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fixedPrices", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getFixedPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getUnderlyingPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getUnderlyingPrices", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isPriceOracle", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pendingOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeFixedPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setBandFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setChainlinkFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFixedPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setLpFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPythFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPythValidTimePeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setWitnetFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "validTimePeriod", data: BytesLike): Result;
}
export declare namespace OwnershipTransferStartedEvent {
    type InputTuple = [previousOwner: AddressLike, newOwner: AddressLike];
    type OutputTuple = [previousOwner: string, newOwner: string];
    interface OutputObject {
        previousOwner: string;
        newOwner: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace OwnershipTransferredEvent {
    type InputTuple = [previousOwner: AddressLike, newOwner: AddressLike];
    type OutputTuple = [previousOwner: string, newOwner: string];
    interface OutputObject {
        previousOwner: string;
        newOwner: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export declare namespace SetFeedEvent {
    type InputTuple = [
        cToken_: AddressLike,
        feedId: BytesLike,
        source: BigNumberish,
        addr: AddressLike,
        feedDecimals: BigNumberish,
        name: string
    ];
    type OutputTuple = [
        cToken_: string,
        feedId: string,
        source: bigint,
        addr: string,
        feedDecimals: bigint,
        name: string
    ];
    interface OutputObject {
        cToken_: string;
        feedId: string;
        source: bigint;
        addr: string;
        feedDecimals: bigint;
        name: string;
    }
    type Event = TypedContractEvent<InputTuple, OutputTuple, OutputObject>;
    type Filter = TypedDeferredTopicFilter<Event>;
    type Log = TypedEventLog<Event>;
    type LogDescription = TypedLogDescription<Event>;
}
export interface FeedPriceOracleSafe extends BaseContract {
    connect(runner?: ContractRunner | null): FeedPriceOracleSafe;
    waitForDeployment(): Promise<this>;
    interface: FeedPriceOracleSafeInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    acceptOwnership: TypedContractMethod<[], [void], "nonpayable">;
    feeds: TypedContractMethod<[
        arg0: AddressLike
    ], [
        [
            string,
            bigint,
            string,
            bigint,
            string
        ] & {
            feedId: string;
            source: bigint;
            addr: string;
            feedDecimals: bigint;
            name: string;
        }
    ], "view">;
    fixedPrices: TypedContractMethod<[arg0: AddressLike], [bigint], "view">;
    getFeed: TypedContractMethod<[
        cToken_: AddressLike
    ], [
        FeedPriceOracle.FeedDataStructOutput
    ], "view">;
    getFixedPrice: TypedContractMethod<[cToken_: AddressLike], [bigint], "view">;
    getUnderlyingPrice: TypedContractMethod<[
        cToken_: AddressLike
    ], [
        bigint
    ], "view">;
    getUnderlyingPrices: TypedContractMethod<[
        cTokens: AddressLike[]
    ], [
        bigint[]
    ], "view">;
    isPriceOracle: TypedContractMethod<[], [boolean], "view">;
    owner: TypedContractMethod<[], [string], "view">;
    pendingOwner: TypedContractMethod<[], [string], "view">;
    removeFeed: TypedContractMethod<[cToken_: AddressLike], [void], "nonpayable">;
    removeFixedPrice: TypedContractMethod<[
        cToken_: AddressLike
    ], [
        void
    ], "nonpayable">;
    renounceOwnership: TypedContractMethod<[], [void], "nonpayable">;
    setBandFeed: TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike,
        feedDecimals_: BigNumberish,
        name: string
    ], [
        void
    ], "nonpayable">;
    setChainlinkFeed: TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike
    ], [
        void
    ], "nonpayable">;
    setFixedPrice: TypedContractMethod<[
        cToken_: AddressLike,
        price: BigNumberish
    ], [
        void
    ], "nonpayable">;
    setLpFeed: TypedContractMethod<[
        cToken_: AddressLike,
        lpToken: AddressLike
    ], [
        void
    ], "nonpayable">;
    setPythFeed: TypedContractMethod<[
        cToken_: AddressLike,
        feedId: BytesLike,
        addr: AddressLike
    ], [
        void
    ], "nonpayable">;
    setPythValidTimePeriod: TypedContractMethod<[
        _validTimePeriod: BigNumberish
    ], [
        void
    ], "nonpayable">;
    setWitnetFeed: TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike,
        feedDecimals_: BigNumberish
    ], [
        void
    ], "nonpayable">;
    transferOwnership: TypedContractMethod<[
        newOwner: AddressLike
    ], [
        void
    ], "nonpayable">;
    validTimePeriod: TypedContractMethod<[], [bigint], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "acceptOwnership"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "feeds"): TypedContractMethod<[
        arg0: AddressLike
    ], [
        [
            string,
            bigint,
            string,
            bigint,
            string
        ] & {
            feedId: string;
            source: bigint;
            addr: string;
            feedDecimals: bigint;
            name: string;
        }
    ], "view">;
    getFunction(nameOrSignature: "fixedPrices"): TypedContractMethod<[arg0: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "getFeed"): TypedContractMethod<[
        cToken_: AddressLike
    ], [
        FeedPriceOracle.FeedDataStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getFixedPrice"): TypedContractMethod<[cToken_: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "getUnderlyingPrice"): TypedContractMethod<[cToken_: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "getUnderlyingPrices"): TypedContractMethod<[cTokens: AddressLike[]], [bigint[]], "view">;
    getFunction(nameOrSignature: "isPriceOracle"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "owner"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "pendingOwner"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "removeFeed"): TypedContractMethod<[cToken_: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "removeFixedPrice"): TypedContractMethod<[cToken_: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "renounceOwnership"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "setBandFeed"): TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike,
        feedDecimals_: BigNumberish,
        name: string
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setChainlinkFeed"): TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setFixedPrice"): TypedContractMethod<[
        cToken_: AddressLike,
        price: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setLpFeed"): TypedContractMethod<[
        cToken_: AddressLike,
        lpToken: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setPythFeed"): TypedContractMethod<[
        cToken_: AddressLike,
        feedId: BytesLike,
        addr: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setPythValidTimePeriod"): TypedContractMethod<[
        _validTimePeriod: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setWitnetFeed"): TypedContractMethod<[
        cToken_: AddressLike,
        feed_: AddressLike,
        feedDecimals_: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "transferOwnership"): TypedContractMethod<[newOwner: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "validTimePeriod"): TypedContractMethod<[], [bigint], "view">;
    getEvent(key: "OwnershipTransferStarted"): TypedContractEvent<OwnershipTransferStartedEvent.InputTuple, OwnershipTransferStartedEvent.OutputTuple, OwnershipTransferStartedEvent.OutputObject>;
    getEvent(key: "OwnershipTransferred"): TypedContractEvent<OwnershipTransferredEvent.InputTuple, OwnershipTransferredEvent.OutputTuple, OwnershipTransferredEvent.OutputObject>;
    getEvent(key: "SetFeed"): TypedContractEvent<SetFeedEvent.InputTuple, SetFeedEvent.OutputTuple, SetFeedEvent.OutputObject>;
    filters: {
        "OwnershipTransferStarted(address,address)": TypedContractEvent<OwnershipTransferStartedEvent.InputTuple, OwnershipTransferStartedEvent.OutputTuple, OwnershipTransferStartedEvent.OutputObject>;
        OwnershipTransferStarted: TypedContractEvent<OwnershipTransferStartedEvent.InputTuple, OwnershipTransferStartedEvent.OutputTuple, OwnershipTransferStartedEvent.OutputObject>;
        "OwnershipTransferred(address,address)": TypedContractEvent<OwnershipTransferredEvent.InputTuple, OwnershipTransferredEvent.OutputTuple, OwnershipTransferredEvent.OutputObject>;
        OwnershipTransferred: TypedContractEvent<OwnershipTransferredEvent.InputTuple, OwnershipTransferredEvent.OutputTuple, OwnershipTransferredEvent.OutputObject>;
        "SetFeed(address,bytes32,uint8,address,uint8,string)": TypedContractEvent<SetFeedEvent.InputTuple, SetFeedEvent.OutputTuple, SetFeedEvent.OutputObject>;
        SetFeed: TypedContractEvent<SetFeedEvent.InputTuple, SetFeedEvent.OutputTuple, SetFeedEvent.OutputObject>;
    };
}
