import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../../common";
export declare namespace PythStructs {
    type PriceStruct = {
        price: BigNumberish;
        conf: BigNumberish;
        expo: BigNumberish;
        publishTime: BigNumberish;
    };
    type PriceStructOutput = [
        price: bigint,
        conf: bigint,
        expo: bigint,
        publishTime: bigint
    ] & {
        price: bigint;
        conf: bigint;
        expo: bigint;
        publishTime: bigint;
    };
}
export interface WstMTRGOracleInterface extends Interface {
    getFunction(nameOrSignature: "feedId" | "getEmaPrice" | "getEmaPriceNoOlderThan" | "getEmaPriceUnsafe" | "getPrice" | "getPriceNoOlderThan" | "getPriceUnsafe" | "getValidTimePeriod" | "mtrgFeed" | "wstMTRG"): FunctionFragment;
    encodeFunctionData(functionFragment: "feedId", values?: undefined): string;
    encodeFunctionData(functionFragment: "getEmaPrice", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getEmaPriceNoOlderThan", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getEmaPriceUnsafe", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getPrice", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getPriceNoOlderThan", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPriceUnsafe", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getValidTimePeriod", values?: undefined): string;
    encodeFunctionData(functionFragment: "mtrgFeed", values?: undefined): string;
    encodeFunctionData(functionFragment: "wstMTRG", values?: undefined): string;
    decodeFunctionResult(functionFragment: "feedId", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getEmaPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getEmaPriceNoOlderThan", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getEmaPriceUnsafe", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPriceNoOlderThan", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPriceUnsafe", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getValidTimePeriod", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mtrgFeed", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "wstMTRG", data: BytesLike): Result;
}
export interface WstMTRGOracle extends BaseContract {
    connect(runner?: ContractRunner | null): WstMTRGOracle;
    waitForDeployment(): Promise<this>;
    interface: WstMTRGOracleInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    feedId: TypedContractMethod<[], [string], "view">;
    getEmaPrice: TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getEmaPriceNoOlderThan: TypedContractMethod<[
        id: BytesLike,
        age: BigNumberish
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getEmaPriceUnsafe: TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getPrice: TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getPriceNoOlderThan: TypedContractMethod<[
        id: BytesLike,
        age: BigNumberish
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getPriceUnsafe: TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getValidTimePeriod: TypedContractMethod<[], [bigint], "view">;
    mtrgFeed: TypedContractMethod<[], [string], "view">;
    wstMTRG: TypedContractMethod<[], [string], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "feedId"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "getEmaPrice"): TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getEmaPriceNoOlderThan"): TypedContractMethod<[
        id: BytesLike,
        age: BigNumberish
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getEmaPriceUnsafe"): TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getPrice"): TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getPriceNoOlderThan"): TypedContractMethod<[
        id: BytesLike,
        age: BigNumberish
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getPriceUnsafe"): TypedContractMethod<[
        id: BytesLike
    ], [
        PythStructs.PriceStructOutput
    ], "view">;
    getFunction(nameOrSignature: "getValidTimePeriod"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "mtrgFeed"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "wstMTRG"): TypedContractMethod<[], [string], "view">;
    filters: {};
}
