import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface GasBoundCallerInterface extends Interface {
    getFunction(nameOrSignature: "gasBoundCall"): FunctionFragment;
    encodeFunctionData(functionFragment: "gasBoundCall", values: [AddressLike, BigNumberish, BytesLike]): string;
    decodeFunctionResult(functionFragment: "gasBoundCall", data: BytesLike): Result;
}
export interface GasBoundCaller extends BaseContract {
    connect(runner?: ContractRunner | null): GasBoundCaller;
    waitForDeployment(): Promise<this>;
    interface: GasBoundCallerInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    gasBoundCall: TypedContractMethod<[
        _to: AddressLike,
        _maxTotalGas: BigNumberish,
        _data: BytesLike
    ], [
        string
    ], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "gasBoundCall"): TypedContractMethod<[
        _to: AddressLike,
        _maxTotalGas: BigNumberish,
        _data: BytesLike
    ], [
        string
    ], "nonpayable">;
    filters: {};
}
