import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface TestInterface extends Interface {
    getFunction(nameOrSignature: "getBlockNumber" | "mul" | "mulTruncate"): FunctionFragment;
    encodeFunctionData(functionFragment: "getBlockNumber", values?: undefined): string;
    encodeFunctionData(functionFragment: "mul", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "mulTruncate", values: [BigNumberish, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "getBlockNumber", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mul", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mulTruncate", data: BytesLike): Result;
}
export interface Test extends BaseContract {
    connect(runner?: ContractRunner | null): Test;
    waitForDeployment(): Promise<this>;
    interface: TestInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    getBlockNumber: TypedContractMethod<[], [bigint], "view">;
    mul: TypedContractMethod<[
        a: BigNumberish,
        b: BigNumberish
    ], [
        [bigint, bigint]
    ], "view">;
    mulTruncate: TypedContractMethod<[
        a: BigNumberish,
        b: BigNumberish
    ], [
        [bigint, bigint]
    ], "view">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "getBlockNumber"): TypedContractMethod<[], [bigint], "view">;
    getFunction(nameOrSignature: "mul"): TypedContractMethod<[
        a: BigNumberish,
        b: BigNumberish
    ], [
        [bigint, bigint]
    ], "view">;
    getFunction(nameOrSignature: "mulTruncate"): TypedContractMethod<[
        a: BigNumberish,
        b: BigNumberish
    ], [
        [bigint, bigint]
    ], "view">;
    filters: {};
}
