import type { BaseContract, BigNumberish, BytesLike, FunctionFragment, Result, Interface, AddressLike, ContractRunner, ContractMethod, Listener } from "ethers";
import type { TypedContractEvent, TypedDeferredTopicFilter, TypedEventLog, TypedListener, TypedContractMethod } from "../../common";
export interface IFraxGaugeFXSRewardsDistributorInterface extends Interface {
    getFunction(nameOrSignature: "acceptOwnership" | "curator_address" | "currentReward" | "distributeReward" | "distributionsOn" | "gauge_whitelist" | "is_middleman" | "last_time_gauge_paid" | "nominateNewOwner" | "nominatedOwner" | "owner" | "recoverERC20" | "setCurator" | "setGaugeController" | "setGaugeState" | "setTimelock" | "timelock_address" | "toggleDistributions"): FunctionFragment;
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "curator_address", values?: undefined): string;
    encodeFunctionData(functionFragment: "currentReward", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "distributeReward", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "distributionsOn", values?: undefined): string;
    encodeFunctionData(functionFragment: "gauge_whitelist", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "is_middleman", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "last_time_gauge_paid", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "nominateNewOwner", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "nominatedOwner", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "recoverERC20", values: [AddressLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setCurator", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "setGaugeController", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "setGaugeState", values: [AddressLike, boolean, boolean]): string;
    encodeFunctionData(functionFragment: "setTimelock", values: [AddressLike]): string;
    encodeFunctionData(functionFragment: "timelock_address", values?: undefined): string;
    encodeFunctionData(functionFragment: "toggleDistributions", values?: undefined): string;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "curator_address", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "currentReward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "distributeReward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "distributionsOn", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "gauge_whitelist", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "is_middleman", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "last_time_gauge_paid", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "nominateNewOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "nominatedOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "recoverERC20", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCurator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setGaugeController", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setGaugeState", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTimelock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "timelock_address", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "toggleDistributions", data: BytesLike): Result;
}
export interface IFraxGaugeFXSRewardsDistributor extends BaseContract {
    connect(runner?: ContractRunner | null): IFraxGaugeFXSRewardsDistributor;
    waitForDeployment(): Promise<this>;
    interface: IFraxGaugeFXSRewardsDistributorInterface;
    queryFilter<TCEvent extends TypedContractEvent>(event: TCEvent, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    queryFilter<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TypedEventLog<TCEvent>>>;
    on<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    on<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(event: TCEvent, listener: TypedListener<TCEvent>): Promise<this>;
    once<TCEvent extends TypedContractEvent>(filter: TypedDeferredTopicFilter<TCEvent>, listener: TypedListener<TCEvent>): Promise<this>;
    listeners<TCEvent extends TypedContractEvent>(event: TCEvent): Promise<Array<TypedListener<TCEvent>>>;
    listeners(eventName?: string): Promise<Array<Listener>>;
    removeAllListeners<TCEvent extends TypedContractEvent>(event?: TCEvent): Promise<this>;
    acceptOwnership: TypedContractMethod<[], [void], "nonpayable">;
    curator_address: TypedContractMethod<[], [string], "view">;
    currentReward: TypedContractMethod<[
        gauge_address: AddressLike
    ], [
        bigint
    ], "view">;
    distributeReward: TypedContractMethod<[
        gauge_address: AddressLike
    ], [
        [bigint, bigint] & {
            weeks_elapsed: bigint;
            reward_tally: bigint;
        }
    ], "nonpayable">;
    distributionsOn: TypedContractMethod<[], [boolean], "view">;
    gauge_whitelist: TypedContractMethod<[arg0: AddressLike], [boolean], "view">;
    is_middleman: TypedContractMethod<[arg0: AddressLike], [boolean], "view">;
    last_time_gauge_paid: TypedContractMethod<[
        arg0: AddressLike
    ], [
        bigint
    ], "view">;
    nominateNewOwner: TypedContractMethod<[
        _owner: AddressLike
    ], [
        void
    ], "nonpayable">;
    nominatedOwner: TypedContractMethod<[], [string], "view">;
    owner: TypedContractMethod<[], [string], "view">;
    recoverERC20: TypedContractMethod<[
        tokenAddress: AddressLike,
        tokenAmount: BigNumberish
    ], [
        void
    ], "nonpayable">;
    setCurator: TypedContractMethod<[
        _new_curator_address: AddressLike
    ], [
        void
    ], "nonpayable">;
    setGaugeController: TypedContractMethod<[
        _gauge_controller_address: AddressLike
    ], [
        void
    ], "nonpayable">;
    setGaugeState: TypedContractMethod<[
        _gauge_address: AddressLike,
        _is_middleman: boolean,
        _is_active: boolean
    ], [
        void
    ], "nonpayable">;
    setTimelock: TypedContractMethod<[
        _new_timelock: AddressLike
    ], [
        void
    ], "nonpayable">;
    timelock_address: TypedContractMethod<[], [string], "view">;
    toggleDistributions: TypedContractMethod<[], [void], "nonpayable">;
    getFunction<T extends ContractMethod = ContractMethod>(key: string | FunctionFragment): T;
    getFunction(nameOrSignature: "acceptOwnership"): TypedContractMethod<[], [void], "nonpayable">;
    getFunction(nameOrSignature: "curator_address"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "currentReward"): TypedContractMethod<[gauge_address: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "distributeReward"): TypedContractMethod<[
        gauge_address: AddressLike
    ], [
        [bigint, bigint] & {
            weeks_elapsed: bigint;
            reward_tally: bigint;
        }
    ], "nonpayable">;
    getFunction(nameOrSignature: "distributionsOn"): TypedContractMethod<[], [boolean], "view">;
    getFunction(nameOrSignature: "gauge_whitelist"): TypedContractMethod<[arg0: AddressLike], [boolean], "view">;
    getFunction(nameOrSignature: "is_middleman"): TypedContractMethod<[arg0: AddressLike], [boolean], "view">;
    getFunction(nameOrSignature: "last_time_gauge_paid"): TypedContractMethod<[arg0: AddressLike], [bigint], "view">;
    getFunction(nameOrSignature: "nominateNewOwner"): TypedContractMethod<[_owner: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "nominatedOwner"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "owner"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "recoverERC20"): TypedContractMethod<[
        tokenAddress: AddressLike,
        tokenAmount: BigNumberish
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setCurator"): TypedContractMethod<[
        _new_curator_address: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setGaugeController"): TypedContractMethod<[
        _gauge_controller_address: AddressLike
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setGaugeState"): TypedContractMethod<[
        _gauge_address: AddressLike,
        _is_middleman: boolean,
        _is_active: boolean
    ], [
        void
    ], "nonpayable">;
    getFunction(nameOrSignature: "setTimelock"): TypedContractMethod<[_new_timelock: AddressLike], [void], "nonpayable">;
    getFunction(nameOrSignature: "timelock_address"): TypedContractMethod<[], [string], "view">;
    getFunction(nameOrSignature: "toggleDistributions"): TypedContractMethod<[], [void], "nonpayable">;
    filters: {};
}
